@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import patterns, url
 
 from django.contrib.admin.views.decorators import staff_member_required
 
@@ -12,5 +12,5 @@ urlpatterns = patterns('',
 for browser in get_enabled_browsers():
     slug = browser.slug()
     urlpatterns += patterns('',
-        url('%s/$' % slug, browser,
+        url('%s/$' % slug, browser.as_view(),
             name='adminfiles_%s' % slug))
