@@ -7,12 +7,11 @@ sys.path.insert(0, parent)
 
 os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.test_settings'
 
-from django.test.utils import get_runner
-from django.conf import settings
-
 def runtests():
-    test_runner = get_runner(settings)
-    failures = test_runner(['tests'], verbosity=1, interactive=True)
+    from django.test.simple import DjangoTestSuiteRunner
+    runner = DjangoTestSuiteRunner(
+        verbosity=1, interactive=True, failfast=False)
+    failures = runner.run_tests(['tests'])
     sys.exit(failures)
 
 if __name__ == '__main__':
